#! /usr/bin/pythonw
# -*- coding: utf-8 -*-
import wx

class MainApp(wx.App):
    """ A wxPython által felkínált application class-ból leszármaztatott
        alkalmazás generálása."""
    def OnInit(self):
        # A főablak generálása
        frame = MainWindow('Párbeszéddoboz')
        self.SetTopWindow(frame)
        return True

    def OnExit(self):
        """ Az alkalmazásból történő kilépés előtt automatikusan hívott metódus"""

        # Egy egyszeru párbeszéddoboz objektum generálása
        dialogue = wx.MessageDialog(None, 'GoodBye!', "message d'au revoir",
                                    wx.OK)

        # a párbeszéddoboz kiíratása
        result = dialogue.ShowModal()
        return True

class MainWindow(wx.Frame):
    """ Egy - az alkalmazásunkra adaptált ablak generálása. A wxPython által felkínált alap ablak-class
        Ezért származtattuk le az ablakunkat a wxPython által felkínált alap ablak-class-ból..."""

    def __init__(self, title):
        # Itt változás van. A frame méretét adjuk meg.
        wx.Frame.__init__(self, None, wx.ID_ANY, title, size=(300, 150))

        # Egy widget-konténert teszünk a frame-be
        self.panel = wx.Panel(self, wx.ID_ANY)

        # Sizer a gombok elhelyezéséhez
        sizer = wx.GridBagSizer(5,5)

        # Gombok elhelyezése a konténerbe
        btnDialog = wx.Button(self.panel, wx.ID_ANY, "Egyszerű párbeszéddoboz",
                              size=(290, 35))
        btnSaisie = wx.Button(self.panel, wx.ID_ANY, "Párbeszéddoboz adatbeírással",
                              size=(290, 35))
        btnChoix1 = wx.Button(self.panel, wx.ID_ANY, "Párbeszéddoboz egyszeres választással",
                               size=(290, 35))
        btnChoix2 = wx.Button(self.panel, wx.ID_ANY, "Párbeszéddoboz többszörös választással",
                               size=(290, 35))
        btnChoix3 = wx.Button(self.panel, wx.ID_ANY, "Egy szín kiválasztása",
                               size=(290, 35))
        btnExit    = wx.Button(self.panel, wx.ID_ANY, "&Kilépés")

        # Sizer hozzáadása
        sizer.Add(btnDialog, (0,0), flag=wx.ALIGN_CENTER|wx.EXPAND|wx.ALL, border=5)
        sizer.Add(btnSaisie, (1,0), flag=wx.ALIGN_CENTER|wx.EXPAND|wx.ALL, border=5)
        sizer.Add(btnChoix1, (2,0), flag=wx.ALIGN_CENTER|wx.EXPAND|wx.ALL, border=5)
        sizer.Add(btnChoix2, (3,0), flag=wx.ALIGN_CENTER|wx.EXPAND|wx.ALL, border=5)
        sizer.Add(btnChoix3, (4,0), flag=wx.ALIGN_CENTER|wx.EXPAND|wx.ALL, border=5)
        sizer.Add(btnExit,   (5,1), flag=wx.ALIGN_BOTTOM|wx.ALIGN_RIGHT)

        sizer.Add((10,10), pos=(6,0), span=(1, 3))   # alsó margó
        sizer.Add((10,10), pos=(0,2), span=(5, 1))   # jobboldali margó

        sizer.AddGrowableRow(5)
        sizer.AddGrowableCol(0)
        sizer.AddGrowableCol(1)

        self.panel.SetSizer(sizer)
        sizer.Fit(self)

        # Metódusok hozzárendelése a gombra történő kattintáshoz
        self.Bind(wx.EVT_BUTTON, self.AfficherDlgSimple, btnDialog)
        self.Bind(wx.EVT_BUTTON, self.AfficherDlgSaisie, btnSaisie)
        self.Bind(wx.EVT_BUTTON, self.AfficherDlgChoixUnique, btnChoix1)
        self.Bind(wx.EVT_BUTTON, self.AfficherDlgChoixMulti, btnChoix2)
        self.Bind(wx.EVT_BUTTON, self.AfficherDlgCouleur, btnChoix3)
        self.Bind(wx.EVT_BUTTON, self.Quitter, btnExit)
        self.SetMinSize((300, 150))
        self.Show(True)

    def Quitter(self, source):
        self.Close()

    def AfficherDlgSimple(self, source):
        """ Egyszerű párbeszéddoboz kiíratása """
        dlgMsg = wx.MessageDialog(None, 'Szereti ezt a példát ?',
                                   'Kérdés',
                                   wx.YES_NO | wx.YES_DEFAULT | wx.ICON_QUESTION)
        reponse = dlgMsg.ShowModal()
        if reponse == wx.ID_YES:
             message = 'Klassz !'
        else:
             message = 'Oh, nem!'
        wx.MessageDialog(self, message, style=wx.OK).ShowModal()
        dlgMsg.Destroy()

    def AfficherDlgSaisie(self, source):
        """Adatbeírásos párbeszéddoboz kiíratása """
        dlgSaisie = wx.TextEntryDialog(self, 'Írja be a keresztnevét',
                                             'Személyes kérdés',
                                             'ide írja be a szöveget',
                                              style=wx.OK|wx.CANCEL)
        # Párbeszéddoboz kiíratása + a visszatérési érték kinyerése
        reponse = dlgSaisie.ShowModal()
        if reponse == wx.ID_OK:
             prenom = dlgSaisie.GetValue()
             wx.MessageDialog(None, 'Bonjour ' + prenom, style=wx.OK).ShowModal()
        dlgSaisie.Destroy()

    def AfficherDlgChoixUnique(self, source):
        """ Egyszeres kiválasztású párbeszéddoboz kiíratása """
        dlgMulti = wx.SingleChoiceDialog(self,
                     'Melyik a kedvenc gyümölcse ?',
                     'Egyszeres választás',
                     [u'őszibarack', u'alma', u'sárgabarack', u'gesztenye', u'szilva'])
        if dlgMulti.ShowModal() == wx.ID_OK:
             fruit = dlgMulti.GetStringSelection()
             wx.MessageDialog(None,
                     u'Egy ' + fruit + u'torta készül', 'Mi készül',
                     style=wx.OK).ShowModal()
        dlgMulti.Destroy()

    def AfficherDlgChoixMulti(self, source):
        """ Többszörös kiválasztású párbeszéddoboz kiíratása """
        fruits = [u'őszibarack', u'alma', u'sárgabarack', u'gesztenye', u'szilva']
        dlgMulti = wx.MultiChoiceDialog(self,
                    'Melyek a kedvenc gyümölcsei ?',
                    'Többszörös választás', fruits)

        if dlgMulti.ShowModal() == wx.ID_OK:
            # a kiválasztott elemek kinyerése egy indexlista formájában
            listeFruits = u""
            for i in dlgMulti.GetSelections():
                listeFruits = listeFruits + fruits[i] + u", "
            wx.MessageDialog(None,
                    u"Éppen egy " + listeFruits + u" torta készül...",
                    style=wx.OK).ShowModal()
        dlgMulti.Destroy()

    def AfficherDlgCouleur(self, source):
        """ A ColourDialog kiíratása """
        dlgCouleur = wx.ColourDialog(self)
        res = dlgCouleur.ShowModal()
        if res == wx.ID_OK:
            # a DataColour kinyerése
            couleur = dlgCouleur.GetColourData()
            # a panel hátterének színezése a kiválasztott színnel
            self.panel.SetBackgroundColour(couleur.GetColour())
        dlgCouleur.Destroy()

if __name__ == "__main__":
    app = MainApp(redirect=False)
    app.MainLoop()




