#! /usr/bin/pythonw
# -*- coding: utf-8 -*-
import wx

class MainApp(wx.App):
    def OnInit(self):
        # A főablak generálása
        frame = MainWindow('Menüs példa')
        self.SetTopWindow(frame)
        return True

class MainWindow(wx.Frame):
    """ Ablak a menük létrehozását bemutató példa számára"""

    def __init__(self, title):
        wx.Frame.__init__(self, None, wx.ID_ANY, title, size=(300, 150))
        panel = wx.Panel(self)

        # Egyszerű címke a menükhöz kapcsolt akciók kiíratásához
        self.texte = wx.StaticText(panel, wx.ID_ANY, "Nincs akció", pos=(30, 50))

        # A menüsáv létrehozása
        self.__createMenuBar()
        self.Show(True)

    def __createMenuBar (self):
        """ privát metódus, ami a menüsávot fogja létrehozni """
        menubar = wx.MenuBar()
        menuFile = wx.Menu()
        menuEdition = wx.Menu()

        # A file menü elemeinek létrehozása és hozzáadása a menühöz
        mnuItemOpen = menuFile.Append(wx.ID_ANY, "&Megnyitás\tCtrl-M")
        menuFile.AppendSeparator()
        menuQuit = menuFile.Append(wx.ID_ANY, "&Kilépés\tCtrl-K")

        # Mac OS X alatt, a menüsáv Quit eleme menu nem képezi részét
        # a File menünek
        if "__WXMAC__" in wx.PlatformInfo:
            wx.App.SetMacExitMenuItemId(menuQuit.GetId())

        # Az Edition menu elemeinek létrehozása
        mnuItemCancel = wx.MenuItem(menuEdition, wx.ID_ANY, "Töröl\tCtrl-T")
        mnuItemRestore = wx.MenuItem(menuEdition,wx.ID_ANY,
                                      "Visszaállít\tCtrl+Shift-V")

        # Egy almenü létrehozása
        sousMenuAction = wx.Menu();
        mnuItemAction1 = sousMenuAction.Append(wx.ID_ANY, "Akció 1")
        mnuItemAction2 = sousMenuAction.Append(wx.ID_ANY, "Akció 2")
        mnuItemAction3 = sousMenuAction.Append(wx.ID_ANY, "Akció 3")

        # A menüpontok hozzáadása az Edition menühöz
        menuEdition.AppendItem(mnuItemCancel)
        menuEdition.AppendItem(mnuItemRestore)
        menuEdition.AppendSeparator()
        menuEdition.AppendMenu(wx.ID_ANY, "Action", sousMenuAction) # Almenü hozzáadása

        # A menük hozzáadása a menüsávhoz
        menubar.Append(menuFile, "File")
        menubar.Append(menuEdition, "Edit")
        self.SetMenuBar(menubar)

        # Események kapcsolása
        self.Bind(wx.EVT_MENU, self.OnOpen, mnuItemOpen)
        self.Bind(wx.EVT_MENU, self.OnQuit, menuQuit)
        self.Bind(wx.EVT_MENU, self.OnAction, mnuItemAction1)
        self.Bind(wx.EVT_MENU, self.OnAction, mnuItemAction2)
        self.Bind(wx.EVT_MENU, self.OnAction, mnuItemAction3)
        self.Bind(wx.EVT_MENU, self.OnNonImplemente, mnuItemCancel)
        self.Bind(wx.EVT_MENU, self.OnNonImplemente, mnuItemRestore)

    def OnQuit (self, evt):
        wx.MessageBox("Bye, bye!")
        self.Close()

    def OnOpen (self, evt):
        self.texte.SetLabel( "Az OnOpen akció hívása" )

    def OnAction (self, evt):
        itemAction = self.GetMenuBar().FindItemById( evt.GetId())
        label = itemAction.GetText()
        self.texte.SetLabel (u"Az %s hívása" % label)

    def OnNonImplemente (self, evt):
        self.texte.SetLabel ("Nincs implementálva akció")

if __name__ == "__main__":
    app = MainApp(redirect=False)
    app.MainLoop()

