#!/usr/bin/env python
# -*- coding: UTF-8 -*-
import wx
class MainWindow(wx.Frame):
    """ Az alkalmazás főablaka. Minden esetre csak egy lesz belőle. """

    def __init__(self, title):
        # A frame-nek 640*480-as kezdő mérete van és nem fog tudni e fölé menni
        wx.Frame.__init__(self, None, wx.ID_ANY, title, size=(320, 200))
        self.SetMinSize(self.GetSize())
        self.SetMaxSize(self.GetSize())

        # A frame különböző widget-jeinek létrehozása
        self.panel = wx.Panel(self)
        self.radioBox = wx.RadioBox(self.panel, wx.ID_ANY,
                                    "Frequence principale",
                                    style = wx.RA_SPECIFY_ROWS,
                                    choices = ("70", "80", "90", "100"),
                                    majorDimension = 0)
        self.checkListBox = wx.CheckListBox(self.panel, wx.ID_ANY,
                                            size = (-1, 114),
                                            style = wx.LB_NEEDED_SB,
                                            choices = ("1", "2", "3", "4"))
        self.resultat = wx.StaticText(self.panel, wx.ID_ANY, "70.0 Hz")

        # Az alapkiíratást és a szükséges esemény-metódus-widget összekapcsolást
        # lehetővé tevő két privát metódus
        self.__do_layout()
        self.__do_binding()

    def __do_layout(self):
        """ A widget-ek létrehozása és elrendezése az ablakban. Ez egy komplett 
            alkalmazása a sizer-ekre vonatkozó elméletnek.
        """
        # Ez az ablak két sorra van felosztva. Az egyik a rádiógomboké
        # és a jelölőnégyzeteké, a másik az eredményé
        mainSizer = wx.FlexGridSizer(rows=2)

        # Ez a sizer kezeli a felhasználó adatbeviteli widget-jeit
        #(radioBox, checkListBox)
        entrySizer = wx.FlexGridSizer(cols=2, hgap=30)
        entrySizer.Add(self.radioBox, 0, 0)
        entrySizer.Add(self.checkListBox, 0, 0)
        mainSizer.Add(entrySizer, 0, 0)
        mainSizer.Add(self.resultat, 0, wx.ALIGN_CENTER)
        self.panel.SetAutoLayout(True)
        self.panel.SetSizer(mainSizer)
        self.Layout()

    def __do_binding(self):
        """ Itt hozzuk létre az erre az ablakra vonatkozó eseménykezelőket
        """
        self.Bind(wx.EVT_RADIOBOX, self.ChangeResult, self.radioBox)
        self.Bind(wx.EVT_CHECKLISTBOX, self.ChangeResult, self.checkListBox)

    def ChangeResult(self, event):
        """ Megváltoztatja az eredményt, ami a kiválasztott elemek összege
        """
        resultNumeric = int(self.radioBox.GetStringSelection())

        for id in range(0, 4):
            if self.checkListBox.IsChecked(id):
                resultNumeric += int(self.checkListBox.GetString(id))
        self.resultat.SetLabel(str(resultNumeric) + ".0 Hz")
        print self.checkListBox.GetSelections()

class MainApp(wx.App):
    """ Az alkalmazás főablakát hozza létre """
    def OnInit(self):
        frame = MainWindow(title="Generateur de frequence")
        self.SetTopWindow(frame)
        frame.Show()
        return 1

if __name__ == "__main__":
    app = MainApp()
    app.MainLoop()

